@@ -4,12 +4,12 @@ package XML::TMX;
 use 5.004;
 use warnings;
 use strict;
-use Exporter ();
-use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.22';
-@ISA = 'Exporter';
-@EXPORT_OK = qw();
+use parent 'Exporter';
+
+our $VERSION = '0.31';
+our @ISA = 'Exporter';
+our @EXPORT_OK = qw();
 
 =encoding utf-8
 
@@ -31,7 +31,7 @@ any useful code, so check sub-modules, please.
 
 XML::TMX::Writer, XML::TMX::Reader, XML::TMX::FromPO
 
-L<XML::Writer(3)>, TMX Specification L<http://www.lisa.org/tmx/tmx.htm>
+L<XML::Writer(3)>, TMX Specification L<https://www.gala-global.org/oscarStandards/tmx/tmx14b.html>
 
 =head1 AUTHOR
 
