@@ -6,8 +6,9 @@ use strict;
 use XML::TMX::Writer;
 use Exporter ();
 
-use vars qw(@ISA @EXPORT_OK);
+use vars qw(@ISA @EXPORT_OK $VERSION);
 
+$VERSION = '0.31';
 @ISA = 'Exporter';
 @EXPORT_OK = qw(&new &parse_dir &create_tmx &clean_tmx);
 
